/* Tailwind CSS Input File */
@import "tailwindcss";
@plugin "@tailwindcss/typography";
@plugin "daisyui" {
  themes: btg-dark --default, dark --prefersdark;
}

@plugin "daisyui/theme" {
  name: "btg-dark";
  default: true;
  prefersdark: true;
  color-scheme: "dark";
  --color-base-100: oklch(25.33% 0.016 252.42);
  --color-base-200: oklch(23.26% 0.014 253.1);
  --color-base-300: oklch(21.15% 0.012 254.09);
  --color-base-content: oklch(97.807% 0.029 256.847);
  --color-primary: oklch(58% 0.233 240);
  --color-primary-content: oklch(96% 0.018 272.314);
  --color-secondary: oklch(65% 0.241 354.308);
  --color-secondary-content: oklch(94% 0.028 342.258);
  --color-accent: oklch(77% 0.152 181.912);
  --color-accent-content: oklch(38% 0.063 188.416);
  --color-neutral: oklch(14% 0.005 285.823);
  --color-neutral-content: oklch(92% 0.004 286.32);
  --color-info: oklch(74% 0.16 232.661);
  --color-info-content: oklch(29% 0.066 243.157);
  --color-success: oklch(76% 0.177 163.223);
  --color-success-content: oklch(37% 0.077 168.94);
  --color-warning: oklch(82% 0.189 84.429);
  --color-warning-content: oklch(41% 0.112 45.904);
  --color-error: oklch(71% 0.194 13.428);
  --color-error-content: oklch(27% 0.105 12.094);
  --radius-selector: 0.5rem;
  --radius-field: 0.25rem;
  --radius-box: 0.5rem;
  --size-selector: 0.25rem;
  --size-field: 0.25rem;
  --border: 1px;
  --depth: 1;
  --noise: 0;
}



@plugin "daisyui/theme" {
  name: "btg-light";
  default: false;
  prefersdark: false;
  color-scheme: "light";
  --color-base-100: oklch(100% 0 0);
  --color-base-200: oklch(93% 0 0);
  --color-base-300: oklch(86% 0 0);
  --color-base-content: oklch(22.389% 0.031 278.072);
  --color-primary: oklch(58% 0.158 241.966);
  --color-primary-content: oklch(100% 0 0);
  --color-secondary: oklch(55% 0.046 257.417);
  --color-secondary-content: oklch(100% 0 0);
  --color-accent: oklch(60% 0.118 184.704);
  --color-accent-content: oklch(100% 0 0);
  --color-neutral: oklch(0% 0 0);
  --color-neutral-content: oklch(100% 0 0);
  --color-info: oklch(60% 0.126 221.723);
  --color-info-content: oklch(100% 0 0);
  --color-success: oklch(62% 0.194 149.214);
  --color-success-content: oklch(100% 0 0);
  --color-warning: oklch(85% 0.199 91.936);
  --color-warning-content: oklch(0% 0 0);
  --color-error: oklch(70% 0.191 22.216);
  --color-error-content: oklch(0% 0 0);
  --radius-selector: 0.25rem;
  --radius-field: 0.25rem;
  --radius-box: 0.25rem;
  --size-selector: 0.25rem;
  --size-field: 0.25rem;
  --border: 1px;
  --depth: 0;
  --noise: 0;
}



@layer base {
  /* Custom base styles */
}

@layer components {
  /* Custom component styles */
}

@layer utilities {
  /* Custom utility classes */
}

@tailwind base;
@tailwind components;
@tailwind utilities;

/* Custom markdown styling using Tailwind Typography */
.markdown {
    color: hsl(var(--color-base-content));
    max-width: none;
}

.markdown p {
    margin-top: 0px;
}

/* Dark mode adjustments */
[data-theme="btg-dark"] .markdown {
    color-scheme: dark;
}

.prose {
  max-width: none;
  color: hsl(var(--color-base-content));
}

/* Fix for list styling consistency */
.prose ul {
  color: hsl(var(--color-base-content));
}

/* Styling for completed tasks and issues */
.task-content.completed, .issue-content.completed {
  color: hsl(var(--color-base-300));
  text-decoration-line: line-through;
}

/* Sprint highlight animation for navigation */
.highlight-sprint {
  animation: highlight-pulse 1s ease-in-out;
}

@keyframes highlight-pulse {
  0% { background-color: transparent; }
  30% { background-color: hsl(var(--color-primary) / 0.15); }
  100% { background-color: transparent; }
}
