"""Add starred field to Task and Issue models

Revision ID: 66357ad41baa
Revises: 1
Create Date: 2025-03-20 13:02:03.316026

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '66357ad41baa'
down_revision = '1'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('issues', schema=None) as batch_op:
        batch_op.add_column(sa.Column('starred', sa.Boolean(), nullable=True))

    with op.batch_alter_table('tasks', schema=None) as batch_op:
        batch_op.add_column(sa.Column('starred', sa.Boolean(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('tasks', schema=None) as batch_op:
        batch_op.drop_column('starred')

    with op.batch_alter_table('issues', schema=None) as batch_op:
        batch_op.drop_column('starred')

    # ### end Alembic commands ###
